==> softcorp_flutter_core-1.0.98.tar.gz: lib/default_card/default_card.dart <==
import 'package:flutter/material.dart';
import 'package:softcorp_flutter_core/hoverBuilder/hoverBuilder.dart';

import '../constants.dart';

class DefaultCard extends StatefulWidget {
  final Color? backgroundColor;
  final Widget child;
  final Color? shadowColor;
  final double? elevation;
  final Function? onTap;

  const DefaultCard(
      {Key? key, this.backgroundColor, required this.child, this.shadowColor, this.elevation, this.onTap})
      : super(key: key);

  @override
  State<StatefulWidget> createState() {
    return _DefaultCardState();
  }
}

class _DefaultCardState extends State<DefaultCard> {
  Color? shadowColor;
  double? elevation;

  @override
  void initState() {
    shadowColor = widget.shadowColor ?? defaultShadow;
    elevation = widget.elevation ?? defaultElevation;
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    Widget defaultCard = Card(
      elevation: elevation,
      color: widget.backgroundColor,
      semanticContainer: true,
      clipBehavior: Clip.antiAliasWithSaveLayer,
      shadowColor: shadowColor,
      shape: RoundedRectangleBorder(
        borderRadius: BorderRadius.circular(defaultCornerRadius),
        side: widget.elevation == 0 ? const BorderSide(
          color: borderColor,
          width: 1.2,
        ) : BorderSide.none,
      ),
      margin: const EdgeInsets.all(10),
      child: widget.child,
    );
    if (widget.onTap != null) {
      Widget raiseOnHoverWidget = RaiseOnHover(builder: (isHovered) {
        return defaultCard;
      });
      Widget onTapWidget = MouseRegion(
        onEnter: (_) {
          setState(() {
            shadowColor = softcorpPrimaryColor;
            elevation = 12.0;
          });
        },
        onExit: (_) {
          setState(() {
            shadowColor = widget.shadowColor ?? defaultShadow;
            elevation = widget.elevation ?? defaultElevation;
          });
        },
        cursor: SystemMouseCursors.click,
        child: GestureDetector(
          onTap: () => widget.onTap!(),
          child: raiseOnHoverWidget,
        ),
      );
      return onTapWidget;
    }
    return defaultCard;
  }
}

==> softcorp_flutter_core-1.0.1013.tar.gz: lib/default_card/default_card.dart <==
import 'package:flutter/material.dart';
import 'package:softcorp_flutter_core/hoverBuilder/hoverBuilder.dart';

import '../constants.dart';

class DefaultCard extends StatefulWidget {
  final Color? backgroundColor;
  final Widget child;
  final Color? shadowColor;
  final double? elevation;
  final Function? onTap;
  final bool? addBorder;
  const DefaultCard(
      {Key? key, this.backgroundColor, required this.child, this.shadowColor, this.elevation, this.onTap, this.addBorder})
      : super(key: key);

  @override
  State<StatefulWidget> createState() {
    return _DefaultCardState();
  }
}

class _DefaultCardState extends State<DefaultCard> {
  Color? shadowColor;
  double? elevation;

  @override
  void initState() {
    shadowColor = widget.shadowColor ?? defaultShadow;
    elevation = widget.elevation ?? defaultElevation;
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    Widget defaultCard = Card(
      elevation: elevation,
      color: widget.backgroundColor,
      semanticContainer: true,
      clipBehavior: Clip.antiAliasWithSaveLayer,
      shadowColor: shadowColor,
      shape: RoundedRectangleBorder(
        borderRadius: BorderRadius.circular(defaultCornerRadius),
        side: (widget.elevation == 0 && widget.addBorder == true) ? const BorderSide(
          color: borderColor,
          width: 1.2,
        ) : BorderSide.none,
      ),
      margin: const EdgeInsets.all(10),
      child: widget.child,
    );
    if (widget.onTap != null) {
      Widget raiseOnHoverWidget = RaiseOnHover(builder: (isHovered) {
        return defaultCard;
      });
      Widget onTapWidget = MouseRegion(
        onEnter: (_) {
          setState(() {
            shadowColor = softcorpPrimaryColor;
            elevation = 12.0;
          });
        },
        onExit: (_) {
          setState(() {
            shadowColor = widget.shadowColor ?? defaultShadow;
            elevation = widget.elevation ?? defaultElevation;
          });
        },
        cursor: SystemMouseCursors.click,
        child: GestureDetector(
          onTap: () => widget.onTap!(),
          child: raiseOnHoverWidget,
        ),
      );
      return onTapWidget;
    }
    return defaultCard;
  }
}
